pub struct UdpRecvMeta {
pub bytes_read: usize,
pub source_addr: SocketAddr,
pub destination_addr: Option<IpAddr>,
pub interface_index: Option<u32>,
}Expand description
Metadata returned from recv_msg.
Fields
bytes_read: usizeNumber of bytes received into the data buffer.
source_addr: SocketAddrSource address of the datagram.
destination_addr: Option<IpAddr>Destination address that received the datagram, if provided by ancillary data.
interface_index: Option<u32>Interface index on which the datagram was received, if provided.